package com.uas.service.Impl;

import com.uas.service.DownloadStcockQtyService;
import com.uas.util.BaseUtil;
import com.uas.util.FileUtil;
import org.apache.commons.net.ftp.FTPClient;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import java.io.File;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.List;
import java.util.Map;

import static com.uas.util.FtpUtil.*;
import static com.uas.util.JdbcUtil.getConnectBySob;
import static com.uas.util.JdbcUtil.getFtpConfigs;

/**
 * @author koul
 * @email koul@usoftchina.com
 * @date 2020-11-27 9:51
 */
@Service
public class DownloadStcockQtyServiceImpl implements DownloadStcockQtyService {

    @Override
    public void downloadQty() {
        //深圳华商龙-准时达
        downloadStcockQty("N_HUASL_SZ-DRD", "N_HUASL_SZ");
        //上海宇声-准时达
        downloadStcockQty("N_E_SHINE_SH-DRD", "N_E_SHINE_SH");
        //重庆华商龙-准时达
        downloadStcockQty("HSL_CQ-DRD", "HSL_CQ");
        //北京华商龙-准时达
        downloadStcockQty("HSL_BJ-DRD", "HSL_BJ");
        //青岛华商龙-准时达
        downloadStcockQty("N_HUASL_QD-DRD", "N_HUASL_QD");
    }

    @Override
    @Async("taskExecutor")
    public void downloadStcockQty(String depot,String sob) {
        BaseUtil.getLogger().info("downloadStcockQty()："+sob+"开始");
        FTPClient client = null;
        Connection connect = null;
        try {
            Map<String,Object> servMap = getFtpConfigs();
            Map<String,Object> ftpMap = (Map<String,Object>)servMap.get(depot);
            client = connect(ftpMap);
            if(client!=null) {
                List<File> files = null;
                files = downloadFileByDirectory(client,ftpMap.get("qty").toString(), "XML");
                String fileName = "";
                if (files != null && files.size() > 0) {
                    connect = getConnectBySob(sob);
                    if (connect != null) {
                        for (File file : files) {
                            try {
                                fileName += "," + file.getName();
                                boolean b = FileUtil.getDataAndSqlByXml(connect, file, sob);
                                if (b) {
                                    //移动处理完的文件到bak文件夹下
                                    client.rename(file.getName(), "bak/" + file.getName());
                                }else {
                                    //移动处理失败的文件到failed文件夹下
                                    client.rename(file.getName(), "failed/" + file.getName());
                                }
                            } catch (Exception e) {
                                e.printStackTrace();
                                BaseUtil.getLogger().error(e.toString());
                                continue;
                            }
                        }

                    }
                    if (!"".equals(fileName)) {
                        BaseUtil.logDownload(fileName.substring(1), ftpMap.get("ip").toString(), ftpMap.get("qty").toString());
                    }
                }
            }
            BaseUtil.getLogger().info("downloadStcockQty()："+sob+"结束");
        } catch (Exception e) {
            BaseUtil.getLogger().error("downloadStcockQty()："+e.getMessage());
            e.printStackTrace();
        }finally{
            if(client!=null){
                closeFtpClient(client);
                client = null;
            }
            //把当前的连接关闭
            try {
                if(connect!=null){
                    connect.close();
                }
            } catch (SQLException e) {
                e.printStackTrace();
            }finally{
                connect = null;
            }
        }
    }
}
