package com.uas.util;

import org.apache.log4j.Logger;
import org.apache.log4j.PropertyConfigurator;

import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;


public class BaseUtil {
	public final static String REG_D = "\\d{4}-\\d{2}-\\d{2}";
	public final static String REG_DT = "\\d{4}-\\d{2}-\\d{2} \\d{2}:\\d{2}";
	public final static String REG_DTS = "\\d{4}-\\d{2}-\\d{2} \\d{2}:\\d{2}:\\d{2}";
	public final static String REG_TS = "\\d{4}-\\d{2}-\\d{2} \\d{2}:\\d{2}:\\d{2}.\\d{1}";
	public static Logger logger;
	
	/**
	 * 获取日志类
	 * @return 日志类
	 */
	public static Logger getLogger(){
		if(logger==null){
			logger = Logger.getLogger(BaseUtil.class);
		    //loger所需的配置文件路径   
			Properties prop = new Properties();
		    try {
				prop.load(BaseUtil.class.getResourceAsStream("/properties/log4j.properties"));
			} catch (IOException e) {
				e.printStackTrace();
			}
		    PropertyConfigurator.configure(prop); 
		}
		return logger;
	}
	
	public static void logDownload(String fileName,String ip,String downloadpath){
		getLogger().info("download " + fileName + " from " + ip + " path:" + downloadpath);
	}

	public static List<String> getInsertSqlbyMaps(List<Map<String, Object>> maps, String table,String mkey,String seq) {
		List<String> sqls = new ArrayList<String>();
		StringBuffer sb1 = null;
		StringBuffer sb2 = null;
		for (Map<String, Object> map : maps) {
			Set<String> keys = map.keySet();
			sb1 = new StringBuffer("INSERT into " + table + " ("+mkey+",");
			sb2 = new StringBuffer(" "+seq+",");
			for (Object key : keys) {
				String field = (String) key;
				Object value = map.get(key);
				sb1.append(field);
				sb1.append(",");
				if (value != null) {
					String val = value.toString();
					if (val.matches(REG_D)) {// 判断是否是形如yyyy-mm-dd格式的日期类型数据
						sb2.append(parseDateToOracleString("yyyy-MM-dd", val));
					} else if (val.matches(REG_DT)) {
						sb2.append(parseDateToOracleString("yyyy-MM-dd HH:mm", val));
					} else if (val.matches(REG_DTS)) {
						sb2.append(parseDateToOracleString("yyyy-MM-dd HH:mm:ss", val));
					} else if (val.matches(REG_TS)) {
						sb2.append(parseDateToOracleString("yyyy-MM-dd HH:mm:ss", val.substring(0, val.lastIndexOf("."))));
					} else if ("null".equals(val)) {
						sb2.append("null");
					} else if ("".equals(val.trim())) {
						sb2.append("''");
					} else if (val.contains("%n")) {
						sb2.append("'" + val.replaceAll("%n", "\n") + "'");
					} else if (val.contains("@N")) {
						sb2.append("" + val.replaceAll("@N", "") + "");
					} else if (val.contains("'")) {
						sb2.append("'" + value.toString().replaceAll("'", "''") + "'");
					} else {
						sb2.append("'" + value + "'");
					}
				} else {
					sb2.append("null");
				}
				sb2.append(",");
			}
			sqls.add(sb1.substring(0, sb1.length() - 1) + ") VALUES (" + sb2.substring(0, sb2.length() - 1) + ")");
		}
		return sqls;
	}

	/**
	 * 日期转化成oracle格式to_date('2012-12-12', 'yyyy-MM-dd')
	 *
	 * @param format
	 *            format type,for example: 'yyyy-MM-dd', 'yyyy-MM-dd HH:mm:ss'
	 * @param dateString
	 *            date{type=string}
	 */
	public static String parseDateToOracleString(String format, String dateString) {
		if (format == null) {
			format = "yyyy-MM-dd";
		}
		if (dateString == null || "".equals(dateString) || "null".equals(dateString)) {
			SimpleDateFormat sdf = new SimpleDateFormat(format);
			dateString = sdf.format(new Date());
		}
		if ("yyyy-MM-dd HH:mm".toUpperCase().equals(format.toUpperCase())) {
			format = "yyyy-MM-dd HH24:mi";
		} else if ("yyyy-MM-dd HH:mm:ss".toUpperCase().equals(format.toUpperCase())) {
			format = "yyyy-MM-dd HH24:mi:ss";
		} else {
			format = "yyyy-MM-dd";
		}
		return "to_date('" + dateString + "','" + format + "')";
	}

	/**
	 * 转换成日期格式字符串
	 * @param date
	 * @param format
	 * @return
	 */
	public static String date2String(Date date,String format) {
		if(format == null || format.isEmpty()){
			format = "yyyy-MM-dd HH:mm:ss";
		}
		SimpleDateFormat sdf = new SimpleDateFormat(format);
		if(date == null){
			return sdf.format(new Date());
		}
		return sdf.format(date);
	}

	/**
	 * 转换成日期格式字符串
	 * @param seconds
	 * @param format
	 * @return
	 */
	public static Date string2Date(String seconds,String format) {
		SimpleDateFormat sdf = new SimpleDateFormat(format);
		try {
			return sdf.parse(seconds);
		} catch (ParseException e) {
			e.printStackTrace();
		}
		return new Date();
	}
}
